@@ -22,7 +22,7 @@ from rekuest.structures.registry import (
 
 
 def convert_child_to_childport(
-    cls, registry, nullable=False
+    cls, registry: StructureRegistry, nullable=False, is_return=False
 ) -> Tuple[ChildPortInput, WidgetInput, Callable]:
 
     if cls.__module__ == "typing":
@@ -102,7 +102,11 @@ def convert_child_to_childport(
 
     identifier = registry.get_identifier_for_structure(cls)
     default_converter = registry.get_default_converter_for_structure(cls)
-    widget = registry.get_widget_input(cls)
+    widget = (
+        registry.get_returnwidget_input(cls)
+        if is_return
+        else registry.get_widget_input(cls)
+    )
 
     return (
         ChildPortInput(
@@ -274,24 +278,24 @@ def convert_return_to_returnport(
         if hasattr(cls, "_name"):
             # We are dealing with a Typing Var?
             if cls._name == "List":
-                child = convert_argument_to_port(
-                    cls.__args__[0], "omit", registry, nullable=False
+                child, widget, converter = convert_child_to_childport(
+                    cls.__args__[0], registry, nullable=False, is_return=True
                 )
                 return ReturnPortInput(
                     kind=PortKindInput.LIST,
-                    widget=widget or child.widget,
+                    widget=widget,
                     key=key,
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
                 )
 
             if cls._name == "Dict":
-                child = convert_argument_to_port(
-                    cls.__args__[1], "omit", registry, nullable=False
+                child, widget, converter = convert_child_to_childport(
+                    cls.__args__[1], registry, nullable=False, is_return=True
                 )
                 return ReturnPortInput(
                     kind=PortKindInput.DICT,
-                    widget=widget or child.widget,
+                    widget=widget,
                     key=key,
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
